==> replicated-config-render-1.0.5.tgz: package/components/ConfigFieldSelectOne.jsx <==
var _ = require('lodash');
var classNames = require('classnames');
var React = require('react');

var ConfigItemTitle = require('./ConfigItemTitle.jsx');
var ConfigFieldRadio = require('./ConfigFieldRadio.jsx');
var Compat = require('../services/Compat.jsx');

var ConfigFieldSelectOne = React.createClass({
  handleItemChange: function(itemName, value) {
    if (value === '1' && this.props.handleChange) {
      this.props.handleChange(this.props.name, itemName);
    }
  },

  render: function() {
    var options = [];
    _.each(this.props.items, function(item) {
      if (!_.isEmpty(item)) {
        // TODO: does required make sense here?
        var title = (
          <ConfigItemTitle
            title={item.title}
            required={item.required === true}
            recommended={item.recommended === true} />
        );

        options.push(
          <div
            key={item.name + '-selectone'}
            className="pull-left"
            style={{paddingRight: '10px'}}>
            <ConfigFieldRadio
              title={title}
              name={item.name}
              group={this.props.name}
              value={this.props.value}
              default={this.props.default}
              readOnly={this.props.readOnly}
              handleChange={this.handleItemChange} />
          </div>
        );
      }
    }.bind(this));

    return (
      <div className="field field-type-selectone">
        <label className={classNames(Compat.hiddenClass('1.0.0'))}>{this.props.title}</label>
        <div className="input input-type-selectone clearfix">
          {options}
        </div>
      </div>
    );
  }
});

module.exports = ConfigFieldSelectOne;

==> replicated-config-render-1.0.6.tgz: package/components/ConfigFieldSelectOne.jsx <==
var _ = require('lodash');
var classNames = require('classnames');
var React = require('react');

var ConfigItemTitle = require('./ConfigItemTitle.jsx');
var ConfigFieldRadio = require('./ConfigFieldRadio.jsx');
var Compat = require('../services/Compat');

var ConfigFieldSelectOne = React.createClass({
  handleItemChange: function(itemName, value) {
    if (value === '1' && this.props.handleChange) {
      this.props.handleChange(this.props.name, itemName);
    }
  },

  render: function() {
    var options = [];
    _.each(this.props.items, function(item) {
      if (!_.isEmpty(item)) {
        // TODO: does required make sense here?
        var title = (
          <ConfigItemTitle
            title={item.title}
            required={item.required === true}
            recommended={item.recommended === true} />
        );

        options.push(
          <div
            key={item.name + '-selectone'}
            className="pull-left"
            style={{paddingRight: '10px'}}>
            <ConfigFieldRadio
              title={title}
              name={item.name}
              group={this.props.name}
              value={this.props.value}
              default={this.props.default}
              readOnly={this.props.readOnly}
              handleChange={this.handleItemChange} />
          </div>
        );
      }
    }.bind(this));

    return (
      <div className="field field-type-selectone">
        <label className={classNames(Compat.hiddenClass('1.0.0'))}>{this.props.title}</label>
        <div className="input input-type-selectone clearfix">
          {options}
        </div>
      </div>
    );
  }
});

module.exports = ConfigFieldSelectOne;
